@@ -9,9 +9,9 @@ use crate::{
 use super::{
     bin_column::{BinColumn, BinColumnIt, BinColumnWriter},
     column_with_indicator::{
-        OptBitColumn, OptDateColumn, OptF32Column, OptF64Column, OptI16Column, OptI32Column,
-        OptI64Column, OptI8Column, OptIt, OptTimeColumn, OptTimestampColumn, OptU8Column,
-        OptWriter,
+        NullableSlice, OptBitColumn, OptDateColumn, OptF32Column, OptF64Column, OptI16Column,
+        OptI32Column, OptI64Column, OptI8Column, OptTimeColumn, OptTimestampColumn, OptU8Column,
+        NullableSliceMut,
     },
     text_column::{TextColumn, TextColumnIt, TextColumnWriter},
     BufferDescription, BufferKind, CharColumn, WCharColumn,
@@ -48,17 +48,17 @@ pub enum AnyColumnView<'a> {
     I64(&'a [i64]),
     U8(&'a [u8]),
     Bit(&'a [Bit]),
-    NullableDate(OptIt<'a, Date>),
-    NullableTime(OptIt<'a, Time>),
-    NullableTimestamp(OptIt<'a, Timestamp>),
-    NullableF64(OptIt<'a, f64>),
-    NullableF32(OptIt<'a, f32>),
-    NullableI8(OptIt<'a, i8>),
-    NullableI16(OptIt<'a, i16>),
-    NullableI32(OptIt<'a, i32>),
-    NullableI64(OptIt<'a, i64>),
-    NullableU8(OptIt<'a, u8>),
-    NullableBit(OptIt<'a, Bit>),
+    NullableDate(NullableSlice<'a, Date>),
+    NullableTime(NullableSlice<'a, Time>),
+    NullableTimestamp(NullableSlice<'a, Timestamp>),
+    NullableF64(NullableSlice<'a, f64>),
+    NullableF32(NullableSlice<'a, f32>),
+    NullableI8(NullableSlice<'a, i8>),
+    NullableI16(NullableSlice<'a, i16>),
+    NullableI32(NullableSlice<'a, i32>),
+    NullableI64(NullableSlice<'a, i64>),
+    NullableU8(NullableSlice<'a, u8>),
+    NullableBit(NullableSlice<'a, Bit>),
 }
 
 /// A mutable borrowed view on the valid rows in a column of a [`crate::buffers::ColumnarRowSet`].
@@ -84,17 +84,17 @@ pub enum AnyColumnViewMut<'a> {
     I64(&'a mut [i64]),
     U8(&'a mut [u8]),
     Bit(&'a mut [Bit]),
-    NullableDate(OptWriter<'a, Date>),
-    NullableTime(OptWriter<'a, Time>),
-    NullableTimestamp(OptWriter<'a, Timestamp>),
-    NullableF64(OptWriter<'a, f64>),
-    NullableF32(OptWriter<'a, f32>),
-    NullableI8(OptWriter<'a, i8>),
-    NullableI16(OptWriter<'a, i16>),
-    NullableI32(OptWriter<'a, i32>),
-    NullableI64(OptWriter<'a, i64>),
-    NullableU8(OptWriter<'a, u8>),
-    NullableBit(OptWriter<'a, Bit>),
+    NullableDate(NullableSliceMut<'a, Date>),
+    NullableTime(NullableSliceMut<'a, Time>),
+    NullableTimestamp(NullableSliceMut<'a, Timestamp>),
+    NullableF64(NullableSliceMut<'a, f64>),
+    NullableF32(NullableSliceMut<'a, f32>),
+    NullableI8(NullableSliceMut<'a, i8>),
+    NullableI16(NullableSliceMut<'a, i16>),
+    NullableI32(NullableSliceMut<'a, i32>),
+    NullableI64(NullableSliceMut<'a, i64>),
+    NullableU8(NullableSliceMut<'a, u8>),
+    NullableBit(NullableSliceMut<'a, Bit>),
 }
 
 #[derive(Debug)]
